local fseablock

local function spawnFish()
  local fish_area = {{-16,-16},{16,16}}
  local surface = fseablock.surface
  if surface.count_entities_filtered({area = fish_area, type = "fish"}) < 6 then
    surface.create_entity({
      name = fseablock.fish[math.random(1,#fseablock.fish)],
      position = {
        x = math.random(-8,9),
        y = math.random(2,5)
      }
    })
  end
end

local function spawnGarden()
  local X0 = 4.8
  local Y0 = -2
  local surface = fseablock.surface
  if surface.count_entities_filtered({position = {x=X0, y=Y0}, type="tree"}) < 1 then
    surface.create_entity({
	  name = fseablock.garden[math.random(1,#fseablock.garden)],
      position = {
        x = X0 + (math.random()/10),
        y = Y0 + (math.random()/10)
      },
    })
  end
end

local function spawnTree()
  local surface = fseablock.surface
  local X0 = 7
  local Y0 = -1
  if surface.count_entities_filtered({position = {x=X0, y=Y0}, type="tree"}) < 1 then
    surface.create_entity({
      name = fseablock.tree[math.random(1,#fseablock.tree)],
      position = {
        x = X0 + (math.random()/10),
        y = Y0 + (math.random()/10),
      },
    })
  end
end

--[[
--Factorio's included event handler is a little weird so here is an example from freeplay
local freeplay = {}
freeplay.events =
{
  [defines.events.on_player_created] = on_player_created,
  [defines.events.on_player_respawned] = on_player_respawned,
  [defines.events.on_cutscene_waypoint_reached] = on_cutscene_waypoint_reached,
  ["crash-site-skip-cutscene"] = skip_crash_site_cutscene,
  [defines.events.on_player_display_resolution_changed] = on_player_display_refresh,
  [defines.events.on_player_display_scale_changed] = on_player_display_refresh,
  [defines.events.on_cutscene_cancelled] = on_cutscene_cancelled,
}
--]]

local custom = {}
custom.on_init = function(event)
  local fsea_table = global.fseablock or {}
  fsea_table.fish = fsea_table.fish or {"fish", "alien-fish-1", "alien-fish-2", "alien-fish-3"}
  fsea_table.garden = fsea_table.garden or { "desert-garden", "swamp-garden", "temperate-garden"}
  fsea_table.tree = fsea_table.tree or {"temperate-tree", "desert-tree", "swamp-tree", "puffer-nest"}

  fsea_table.surface = fsea_table.surface or game.surfaces.nauvis -- nauvis is guaranteed to exist

  fseablock = fsea_table
  global.fseablock = fsea_table
end
custom.on_configuration_changed = custom.on_init

custom.on_load = function()
  fseablock = global.fseablock
end

--3600 ticks = 1 minute
--25000 = 1 default day
custom.on_nth_tick = {
  [16200] = spawnFish, -- 16200 = 4.5 minutes
  [57000] = spawnTree, -- 57000 = 15.833 minutes
  [87600] = spawnGarden, -- 87600 = 24.33 minutes
}

return custom